@@ -1,3 +1,23 @@
+/*
+ *  Copyright 2006 Michael Maurer <mjmaurer@yahoo.com>, 
+ *                 Brian Goetz <brian@quiotix.com>, 
+ *                 Loic Dachary <loic@gnu.org>, 
+ *                 Tim Showalter <tjs@psaux.com>
+ *
+ *  This package is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 dated June, 1991.
+ *
+ *  This package is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this package; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
+ *  MA 02110-1301, USA.
+ */
 /* $Id$
    Example showing how to calculate pot equity using the enumeration functions.
    See also hcmp2.c and hcmpn.c for slightly lower level examples.
@@ -222,7 +242,7 @@ int
 main(int argc, char **argv) {
   enum_game_t game;
   enum_sample_t enumType;
-  int niter, npockets, nboard, err, terse, orderflag;
+  int niter = 0, npockets, nboard, err, terse, orderflag;
   StdDeck_CardMask pockets[ENUM_MAXPLAYERS];
   StdDeck_CardMask board;
   StdDeck_CardMask dead;
