@@ -1,21 +1,21 @@
 /*
- * Copyright (C) 2004 
+ * Copyright (C) 2004-2006
  *           Michael Maurer <mjmaurer@yahoo.com>
  *           Loic Dachary <loic@gnu.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ *  This package is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 dated June, 1991.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ *  This package is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  You should have received a copy of the GNU General Public License
+ *  along with this package; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
+ *  MA 02110-1301, USA.
  */
 /* $Id$ */
 /*
@@ -105,6 +105,7 @@
 #define ENUMORD_H
 
 #include "pokereval_export.h"
+#include "poker_defs.h"
 
 /* largest integer N such that N * ENUM_ORDERING_NBITS(N) < 32 */
 #define ENUM_ORDERING_MAXPLAYERS 7
@@ -134,7 +135,7 @@ typedef struct {
 } enum_ordering_t;
 
 extern POKEREVAL_EXPORT int enum_nbits[ENUM_ORDERING_MAXPLAYERS+1];
-extern POKEREVAL_EXPORT void enum_ordering_rank(int *hands, int noqual,
+extern POKEREVAL_EXPORT void enum_ordering_rank(HandVal *hands, int noqual,
                                int nplayers, int *ranks, int reverse);
 
 /* the bit field size for one player's relative hand rank */
